@@ -1,4 +1,4 @@
 from .sankey_chart import getSankey,transform_data_for_sankey
 from .heatmap import heatmap, correlation_heatmap, Heatmap_Survey_group_difference, Heatmap_group_difference, Heatmap_Survey_group_difference_v2
-from .barplot import stacked_bar_chart, show_values_on_bars, show_values_on_bars_h
+from .barplot import stacked_bar_chart, stacked_bar_chart2, show_values_on_bars, show_values_on_bars_h
 from .cleveland_plot import cleveland_plot,cleveland_plot_v2
\ No newline at end of file
